//-------------------------------------------------------------------------------------------------
// <copyright file="AttestationClient.h" company="Microsoft Corporation">
// Copyright (c) Microsoft Corporation.  All rights reserved.
// </copyright>
//-------------------------------------------------------------------------------------------------
#pragma once

#include <memory>

#include "AttestationLogger.h"
#include "AttestationLibTypes.h"

#ifdef ATTESTATIONLIB_EXPORTS
#define DllExports __declspec(dllexport)
#else
#define DllExports
#endif

class AttestationClient {
public:

    /**
     * @brief This function will be used to initiate an attestation request
     * with the Attestation Client lib
     * @param[in] client_params Struct ClientParameters object containing the
     * parameters from the client needed for attestation.
     * @param[out] jwt_token The decrypted jwt token that will be returned by MAA as
     * a response to the attestation request.
     * @return In case of success, AttestationResult object with error code
     * ErrorCode::Success will be returned.
     * In case of failure, an appropriate ErrorCode will be set in the
     * AttestationResult object and error description will be provided.
     */
    DllExports
    virtual attest::AttestationResult Attest(const attest::ClientParameters& client_params,
                                             std::string& jwt_token) noexcept = 0;
    /**
     * @brief This function will be used to intialize the client lib.
     * @param[in] logging_interface The handle that will be used for logging.
     * @param[out] client AttestationClient object that will be populated and
     * returned when Init succeeds.
     * @return In case of success, true will be returned and client will be
     * populated with an object of AttestationClient. On failure, false will be
     * returned.
     */
    DllExports
    static bool Init(const std::shared_ptr<attest::AttestationLogger>& log_handle,
                     std::shared_ptr<AttestationClient>& client) noexcept;
};
